@@ -3,12 +3,18 @@ Parsel lets you extract text from XML/HTML documents using XPath
 or CSS selectors
 """
 
-__author__ = 'Scrapy project'
-__email__ = 'info@scrapy.org'
-__version__ = '1.5.2'
+__author__ = "Scrapy project"
+__email__ = "info@scrapy.org"
+__version__ = "1.7.0"
+__all__ = [
+    "Selector",
+    "SelectorList",
+    "css2xpath",
+    "xpathfuncs",
+]
 
 from parsel.selector import Selector, SelectorList  # NOQA
 from parsel.csstranslator import css2xpath  # NOQA
-from parsel import xpathfuncs # NOQA
+from parsel import xpathfuncs  # NOQA
 
 xpathfuncs.setup()
